@@ -19,14 +19,13 @@
  *
  */
 
-#ifndef _PROCPROPERTIES_H_
-#define _PROCPROPERTIES_H_
+#ifndef _GSM_PROCPROPERTIES_H_
+#define _GSM_PROCPROPERTIES_H_
 
 #include <glib.h>
 
-#include "procman-app.h"
+#include "application.h"
 
-void create_procproperties_dialog (ProcmanApp *app);
-
-#endif
+void create_procproperties_dialog (GsmApplication *app);
 
+#endif /* _GSM_PROCPROPERTIES_H_ */
